@@ -1,8 +1,8 @@
 # frozen_string_literal: true
 
-require 'test_helper'
+require_relative 'test_helper'
 
-class ZipExtraFieldUnknownTest < MiniTest::Test
+class ZipExtraFieldUnknownTest < Minitest::Test
   def test_new
     extra = ::Zip::ExtraField::Unknown.new
     assert_empty(extra.to_c_dir_bin)
