@@ -1,7 +1,9 @@
 # frozen_string_literal: true
 
-require 'test_helper'
-class InflaterTest < MiniTest::Test
+require_relative 'test_helper'
+require_relative 'helpers/decompressor_tests'
+
+class InflaterTest < Minitest::Test
   include DecompressorTests
 
   def setup
