@@ -1,10 +1,11 @@
 # frozen_string_literal: true
 
-require 'test_helper'
-require 'fileutils'
+require_relative '../test_helper'
 require_relative '../../samples/example_recursive'
 
-class ExampleRecursiveTest < MiniTest::Test
+require 'fileutils'
+
+class ExampleRecursiveTest < Minitest::Test
   DIRECTORY_TO_ZIP  = 'test/data/globTest'
   OUTPUT_DIRECTORY  = 'test/data/example_recursive.zip'
   TEMP_DIRECTORY    = 'test/data/tmp'
