@@ -1,8 +1,10 @@
 # frozen_string_literal: true
 
-require 'test_helper'
+require_relative 'test_helper'
 
-class VersionTest < MiniTest::Test
+require 'zip/version'
+
+class VersionTest < Minitest::Test
   def test_version
     # Ensure all our versions numbers have at least MAJOR.MINOR.PATCH
     # elements separated by dots, to comply with Semantic Versioning.
